==> haskell-lens-aeson-1.0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.1
id: lens-aeson-1.0.1-78iXiz398CU3HCVw86ZZ6p
key: lens-aeson-1.0.1-78iXiz398CU3HCVw86ZZ6p
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Aeson.Lens
abi: 5d4ee42437fcf85434abc01efa58ce94
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/lens-aeson-1.0.1
hs-libraries: HSlens-aeson-1.0.1-78iXiz398CU3HCVw86ZZ6p
depends:
    aeson-1.1.2.0-KxdCZ7gJzCsHXfqqwVMGzQ
    attoparsec-0.13.1.0-KaQFES0So1u93CSgT9OS1a base-4.9.0.0
    bytestring-0.10.8.1 lens-4.15.2-AMe59JL4knEI5ISbnCA6nW
    scientific-0.3.4.13-4xwcJxzSIhZ6kELOWf7cDt
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.1
id: lens-aeson-1.0.1-GmzaixCBeNu9PmjYmORuPA
key: lens-aeson-1.0.1-GmzaixCBeNu9PmjYmORuPA
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Aeson.Lens
abi: f11dc74b8a786fdb1db968dc85ffb68d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lens-aeson-1.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/lens-aeson-1.0.1
hs-libraries: HSlens-aeson-1.0.1-GmzaixCBeNu9PmjYmORuPA
depends:
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH
    attoparsec-0.13.1.0-oc29svN3SiFq1TojBIbwV base-4.9.0.0
    bytestring-0.10.8.1 lens-4.15.2-AMe59JL4knEI5ISbnCA6nW
    scientific-0.3.4.15-GEIRVwGBHHyElVCNt38fm3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
